@@ -14,11 +14,11 @@ String::Copyright - Representation of text-based copyright statements
 
 =head1 VERSION
 
-Version 0.003008
+Version 0.003009
 
 =cut
 
-our $VERSION = '0.003008';
+our $VERSION = '0.003009';
 
 # Dependencies
 use parent 'Exporter::Tiny';
@@ -98,10 +98,12 @@ see the L<Exporter::Tiny> documentation for details.
 # AND'ed strings have name ending in underscore: must be grouped if repeated
 my $blank           = '[ \t]';
 my $blank_or_break_ = "$blank*\\n?$blank*";
-my $sign = '(?i:copyright(?:-holders?)?\b|copr\.|[©⒞Ⓒⓒ🄒🄫🅒])';
-my $pseudo_sign_ = '[({][Cc][})]';
-my $broken_sign_ = "\\?$blank*";
-my $nonsign      = "(?:no |_)copyright|copyright-[^h]";
+my $label           = '(?i:copyright(?:-holders?)?\b|copr\.)';
+my $sign            = '[©⒞Ⓒⓒ🄒🄫🅒]';
+my $pseudo_sign_    = '[({][Cc][})]';
+my $broken_sign_    = "\\?$blank*";
+my $nonidentifier_
+	= "(?:no |_)copyright|copyright-[^h]|(?:Digital Millennium|U.S.|US|United States) Copyright Act|\\bwe copyright\\b";
 
 my $year_ = '\b[0-9]{4}\b';
 my $comma = "(?:$blank*,$blank_or_break_|$blank_or_break_,?$blank*)";
@@ -117,19 +119,20 @@ my $owner_initial = '[^\s!"#$%&\'()*+,./:;<=>?@[\\\\\]^_`{|}~]';
 # (?i)copyright (?:(?:claim|holder|info|information|notice|owner|ownership|statement|string)s?|in|is|to)@\w
 # (?i)copyright (?:(?:claim|holder|info|information|notice|owner|ownership|statement|string)s?|in|is|to)@\b[-_@]
 # (?im)copyright (?:(?:claim|holder|info|information|notice|owner|ownership|statement|string)s?|in|is|to)[^ $]
+my $nonyears = '(?:<?year>?|19yy|yyyy)';
 my $chatter_copyright
-	= '(?i:assigned|transfer(?:red)?|(?:block|claim|holder|info|information|law|notice|owner|ownership|statement|string|tag)s?|and|appl(?:y|ie[ds])|at|eq|generated|in|is|on|or|to)';
+	= '(?i:assigned|transfer(?:red)?|(?:block|claim|disclaimer|holder|info|information|interest|law|notice|owner|ownership|permission|statement|string|tag|the (?:library|software),|treaty)s?|and|appl(?:y|ie[ds])|are|at|eq|generated|if|in|is|on|or|to)';
 my $the_notname
 	= '(?i:concrete|fault|first|immediately|least|min\/max|one|outer|previous|ratio|sum|user)';
 my $the_sentence_
 	= "(?:\\w+$blank+){1,10}(?i:are|can(?:not)?|in|is|must|was)";
 my $chatter_pseudosign_
-	= "(?:the$blank+(?:$the_notname|$the_sentence_)|there)\\b";
+	= "(?:the$blank+(?:$the_notname|$the_sentence_)|there|you must)\\b";
 my $chatter
-	= "(?im:$nonsign|copyright$blank_or_break_$chatter_copyright(?:$|@\\W|[^a-zA-Z0-9@_-])|$blank*$pseudo_sign_(?:$blank_or_break_)+$chatter_pseudosign_)";
+	= "(?im:$nonidentifier_|copyright$blank_or_break_$chatter_copyright(?:$|@\\W|[^a-zA-Z0-9@_-])|$blank*$pseudo_sign_(?:$blank_or_break_)+$chatter_pseudosign_)";
 
 my $signs
-	= "(?m:(?:$sign|(?:^|$blank)$pseudo_sign_):?(?:$blank*(?:$sign|$pseudo_sign_))*)";
+	= "(?m:(?:$label|$sign|(?:^|$blank)$pseudo_sign_):?(?:$blank*(?:$label|$sign|$pseudo_sign_))*)";
 my $yearspan_ = "$year_(?:$dash_$year_)?";
 my $years_    = qr/$yearspan_(?:$comma$yearspan_)*/;
 my $owners_   = "$owner_prefix*$owner_initial\\S*(?:$blank*\\S+)*";
@@ -138,7 +141,7 @@ my $dash_re          = qr/$dash_/;
 my $owner_intro_A_re = qr/^$owner_intro_/;
 my $boilerplate_X_re = qr/(?i)${comma}All$blank+Rights$blank+Reserved[.!]?.*/;
 my $signs_and_more_re
-	= qr/$chatter.*|$signs(?::$blank_or_break_|$comma)(?:$broken_sign_)?($years_?$comma?(?:$owner_intro_)?(?:$owners_)?)|(?:\n|\z)/;
+	= qr/$chatter.*|$signs(?::$blank_or_break_|$comma)(?:$broken_sign_)?(?:$nonyears|((?:$years_$comma?)?(?:(?:$owner_intro_)?$owners_)?))|(?:\n|\z)/;
 
 sub _generate_copyright
 {
